
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef dtm_MSG_LIB_H
#define dtm_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "dtmType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  DTM_MBOX_NAME                  genomInstanceName("dtm")

#define  DTM_MAX_RQST_SIZE              656

#define  DTM_MBOX_RQST_SIZE       \
 (BUF_SIZE(DTM_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  DTM_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  DTM_MAX_REPLY_SIZE             140

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  DTM_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(DTM_MAX_REPLY_SIZE) \
   + BUF_SIZE(DTM_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define DTM_GETINITPARAMS_RQST 0
#define DTM_INIT_RQST 1
#define DTM_CONNECT_RQST 2
#define DTM_REINIT_RQST 3
#define DTM_SETGEODESICORIGIN_RQST 4
#define DTM_GETGEODESICORIGIN_RQST 5
#define DTM_SETFUSIONPARAMS_RQST 6
#define DTM_GETFUSIONPARAMS_RQST 7
#define DTM_FUSEDTM_RQST 8
#define DTM_JUMPDTM_RQST 9
#define DTM_SETP3DPOSTERPARAMS_RQST 10
#define DTM_GETP3DPOSTERPARAMS_RQST 11
#define DTM_FILLP3DPOSTER_RQST 12
#define DTM_FILLLABELPOSTER_RQST 13
#define DTM_SETSAVEPARAMS_RQST 14
#define DTM_GETSAVEPARAMS_RQST 15
#define DTM_SAVEINTERNALDTM_RQST 16
#define DTM_SAVEP3DPOSTER_RQST 17
#define DTM_ABORT_RQST 18


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS dtmClientInit (CLIENT_ID *pClientId);

STATUS dtmClientEnd (CLIENT_ID clientId);

int dtmAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int dtmAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int dtmAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS dtmGetInitParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int dtmGetInitParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       DtmInitParams *(out_initParams),
			       int *bilan);

int dtmGetInitParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 DtmInitParams *(out_initParams),
				 int *bilan);




extern STATUS dtmInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 DtmInitParams *(in_initParams),
					 int replyTimeOut);

extern int dtmInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int dtmInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					DtmInitParams *(in_initParams), 
					
					int *activity, int *bilan);

extern int dtmInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					DtmInitParams *(in_initParams), 
					
					int *activity,
					int *bilan);




extern STATUS dtmConnectRqstSend (CLIENT_ID clientId, int *pRqstId,
					 DtmConnectParams *(in_connectionParams),
					 int replyTimeOut);

extern int dtmConnectReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int dtmConnectRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					DtmConnectParams *(in_connectionParams), 
					
					int *activity, int *bilan);

extern int dtmConnectRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					DtmConnectParams *(in_connectionParams), 
					
					int *activity,
					int *bilan);




extern STATUS dtmReInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 DtmResetParams *(in_resetParams),
					 int replyTimeOut);

extern int dtmReInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int dtmReInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					DtmResetParams *(in_resetParams), 
					
					int *activity, int *bilan);

extern int dtmReInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					DtmResetParams *(in_resetParams), 
					
					int *activity,
					int *bilan);




extern STATUS dtmSetGeodesicOriginRqstSend (CLIENT_ID clientId, int *pRqstId,
					 DtmGeodesicOrigin *(in_geodesicOrigin),
					 int replyTimeOut);

extern int dtmSetGeodesicOriginReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int dtmSetGeodesicOriginRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					DtmGeodesicOrigin *(in_geodesicOrigin), 
					
					int *activity, int *bilan);

extern int dtmSetGeodesicOriginRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					DtmGeodesicOrigin *(in_geodesicOrigin), 
					
					int *activity,
					int *bilan);




extern STATUS dtmGetGeodesicOriginRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int dtmGetGeodesicOriginReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       DtmGeodesicOrigin *(out_geodesicOrigin),
			       int *bilan);

int dtmGetGeodesicOriginRqstAndRcv (CLIENT_ID clientId, 
				  
				 DtmGeodesicOrigin *(out_geodesicOrigin),
				 int *bilan);




extern STATUS dtmSetFusionParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 DtmFusionParams *(in_fusionParams),
					 int replyTimeOut);

int dtmSetFusionParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int dtmSetFusionParamsRqstAndRcv (CLIENT_ID clientId, 
				 DtmFusionParams *(in_fusionParams), 
				 
				 int *bilan);




extern STATUS dtmGetFusionParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int dtmGetFusionParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       DtmFusionParams *(out_fusionParams),
			       int *bilan);

int dtmGetFusionParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 DtmFusionParams *(out_fusionParams),
				 int *bilan);




extern STATUS dtmFuseDtmRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int dtmFuseDtmReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int dtmFuseDtmRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int dtmFuseDtmRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS dtmJumpDtmRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int dtmJumpDtmReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int dtmJumpDtmRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int dtmJumpDtmRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS dtmSetP3dPosterParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 DtmPosterParams *(in_p3dPosterParams),
					 int replyTimeOut);

int dtmSetP3dPosterParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int dtmSetP3dPosterParamsRqstAndRcv (CLIENT_ID clientId, 
				 DtmPosterParams *(in_p3dPosterParams), 
				 
				 int *bilan);




extern STATUS dtmGetP3dPosterParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int dtmGetP3dPosterParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       DtmPosterParams *(out_p3dPosterParams),
			       int *bilan);

int dtmGetP3dPosterParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 DtmPosterParams *(out_p3dPosterParams),
				 int *bilan);




extern STATUS dtmFillP3dPosterRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int dtmFillP3dPosterReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int dtmFillP3dPosterRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int dtmFillP3dPosterRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS dtmFillLabelPosterRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int dtmFillLabelPosterReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int dtmFillLabelPosterRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int dtmFillLabelPosterRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS dtmSetSaveParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 DtmSaveParams *(in_saveParams),
					 int replyTimeOut);

int dtmSetSaveParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int dtmSetSaveParamsRqstAndRcv (CLIENT_ID clientId, 
				 DtmSaveParams *(in_saveParams), 
				 
				 int *bilan);




extern STATUS dtmGetSaveParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int dtmGetSaveParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       DtmSaveParams *(out_saveParams),
			       int *bilan);

int dtmGetSaveParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 DtmSaveParams *(out_saveParams),
				 int *bilan);




extern STATUS dtmSaveInternalDtmRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int dtmSaveInternalDtmReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int dtmSaveInternalDtmRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int dtmSaveInternalDtmRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS dtmSaveP3dPosterRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int dtmSaveP3dPosterReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int dtmSaveP3dPosterRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int dtmSaveP3dPosterRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* dtm_MSG_LIB_H */

